@@ -1,10 +1,13 @@
 import argparse
+from typing import List
+
+from slack_sdk.web.slack_response import SlackResponse
 
 from hartware_lib.adapters.slack import SlackAdapter
-from hartware_lib.settings import SlackBotSettings, load_settings
+from hartware_lib.settings import load_settings, SlackBotSettings
 
 
-def slack_send(command: list = []):
+def slack_send(command: List[str] | None = None) -> SlackResponse:
     parser = argparse.ArgumentParser(description="Slack message sender.")
     parser.add_argument("message", help="set the message")
     parser.add_argument("-c", "--channel", help="set the channel")
